/**
 * <b>Array</b>
 * <p>
 * The JavaScript Array global object is a constructor for arrays, which are high-level, list-like objects.
 * </p>
 * @type Array
 */
var Array = {
/**
 * <b>splice</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.splice(<em>index</em>,<em>howMany</em>[<em>,</em><em>element1</em>[,...[,<em>elementN</em>]]])</code><br/><code><em>array</em>.splice(<em>index</em>[,<em>howMany</em>[,<em>element1</em>[,...[,<em>elementN</em>]]]])</code>
 * </p>
 * <p>
 * Changes the content of an array, adding new elements while removing old elements.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>element1, ..., elementN</b></td>
 * <td>The elements to add to the array. If you don't specify any elements, splice simply removes elements from the array.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>index</b></td>
 * <td>Index at which to start changing the array. If negative, will begin that many elements from the end.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>howMany</b></td>
 * <td>An integer indicating the number of old array elements to remove. If howMany is 0, no elements are removed. In this case, you should specify at least one new element. If no howMany parameter is specified (second syntax above, which is a SpiderMonkey extension), all elements after index are removed.</td>
 * </tr>
 * </table>
 * @type Array
 */
splice: function() {},

/**
 * <b>toSource</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.toSource()</code>
 * </p>
 * <p>
 * Returns a string representing the source code of the array.
 * </p>
 * @type String
 */
toSource: function() {},

/**
 * <b>sort</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.sort([<em>compareFunction</em>])</code>
 * </p>
 * <p>
 * Sorts the elements of an array in place and returns the array. Works across all browsers.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>compareFunction</b></td>
 * <td>Specifies a function that defines the sort order. If omitted, the array is sorted lexicographically (in dictionary order) according to the string conversion of each element.</td>
 * </tr>
 * </table>
 * @type Array
 */
sort: function() {},

/**
 * <b>reduceRight</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.reduceRight(<em>callback</em>[,<em>initialValue</em>])</code>
 * </p>
 * <p>
 * Apply a function simultaneously against two values of the array (from right-to-left) as to reduce it to a single value.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>callback initialValue</b></td>
 * <td>Function to execute on each value in the array. Object to use as the first argument to the first call of the callback.</td>
 * </tr>
 * </table>
 * @type Object
 */
reduceRight: function() {},

/**
 * <b>pop</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.pop()</code>
 * </p>
 * <p>
 * Removes the last element from an array and returns that element.
 * </p>
 * @type Object
 */
pop: function() {},

/**
 * <b>indexOf</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.indexOf(<em>searchElement</em>[,<em>fromIndex</em>])</code>
 * </p>
 * <p>
 * Returns the first index at which a given element can be found in the array, or -1 if it is not present.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>searchElement fromIndex</b></td>
 * <td>Element to locate in the array. The index at which to begin the search. Defaults to 0, i.e. the whole array will be searched. If the index is greater than or equal to the length of the array, -1 is returned, i.e. the array will not be searched. If negative, it is taken as the offset from the end of the array. Note that even when the index is negative, the array is still searched from front to back. If the calculated index is less than 0, the whole array will be searched.</td>
 * </tr>
 * </table>
 * @type Number
 */
indexOf: function() {},

/**
 * <b>every</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.every(<em>callback</em>[,<em>thisObject</em>])</code>
 * </p>
 * <p>
 * Tests whether all elements in the array pass the test implemented by the provided function.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>callback thisObject</b></td>
 * <td>Function to test for each element. Object to use as this when executing callback.</td>
 * </tr>
 * </table>
 * @type Boolean
 */
every: function() {},

/**
 * <b>prototype</b>
 * <p>
 * Represents the prototype for the Array constructor.
 * </p>
 * @type Object
 * @static
 */
prototype: undefined,

/**
 * <b>push</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.push(<em>element1</em>,...,<em>elementN</em>)</code>
 * </p>
 * <p>
 * Mutates an array by appending the given elements and returning the new length of the array.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>element1, ..., elementN</b></td>
 * <td>The elements to add to the end of the array.</td>
 * </tr>
 * </table>
 * @type Number
 */
push: function() {},

/**
 * <b>length</b>
 * <p>
 * An unsigned, 32-bit integer that specifies the number of elements in an array.
 * </p>
 * @type Number
 */
length: undefined,

/**
 * <b>map</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.map(<em>callback</em>[,<em>thisArg</em>])</code>
 * </p>
 * <p>
 * Creates a new array with the results of calling a provided function on every element in this array.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>callback thisArg</b></td>
 * <td>Function that produces an element of the new Array from an element of the current one. Object to use as this when executing callback.</td>
 * </tr>
 * </table>
 * @type Array
 */
map: function() {},

/**
 * <b>unshift</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>arrayName</em>.unshift(<em>element1</em>,...,<em>elementN</em>)</code>
 * </p>
 * <p>
 * Adds one or more elements to the beginning of an array and returns the new length of the array.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>element1, ..., elementN</b></td>
 * <td>The elements to add to the front of the array.</td>
 * </tr>
 * </table>
 * @type Number
 */
unshift: function() {},

/**
 * <b>constructor</b>
 * <p>
 * Returns a reference to the Array function that created the instance's prototype. Note that the value of this property is a reference to the function itself, not a string containing the function's name.
 * </p>
 * @type Function
 */
constructor: undefined,

/**
 * <b>reverse</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.reverse()</code>
 * </p>
 * <p>
 * Reverses an array in place.  The first array element becomes the last and the last becomes the first.
 * </p>
 * @type Array
 */
reverse: function() {},

/**
 * <b>forEach</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.forEach(<em>callback</em>[,<em>thisArg</em>])</code>
 * </p>
 * <p>
 * Executes a provided function once per array element.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>callback thisArg</b></td>
 * <td>Function to execute for each element. Object to use as this when executing callback.</td>
 * </tr>
 * </table>
 * @type undefined
 */
forEach: function() {},

/**
 * <b>lastIndexOf</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.lastIndexOf(<em>searchElement</em>[,<em>fromIndex</em>])</code>
 * </p>
 * <p>
 * Returns the last index at which a given element can be found in the array, or -1 if it is not present. The array is searched backwards, starting at fromIndex.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>searchElement fromIndex</b></td>
 * <td>Element to locate in the array. The index at which to start searching backwards. Defaults to the array's length, i.e. the whole array will be searched. If the index is greater than or equal to the length of the array, the whole array will be searched. If negative, it is taken as the offset from the end of the array. Note that even when the index is negative, the array is still searched from back to front. If the calculated index is less than 0, -1 is returned, i.e. the array will not be searched.</td>
 * </tr>
 * </table>
 * @type Number
 */
lastIndexOf: function() {},

/**
 * <b>join</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.join(<em>separator</em>)</code>
 * </p>
 * <p>
 * Joins all elements of an array into a string.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>separator</b></td>
 * <td>Specifies a string to separate each element of the array. The separator is converted to a string if necessary. If omitted, the array elements are separated with a comma.</td>
 * </tr>
 * </table>
 * @type String
 */
join: function() {},

/**
 * <b>concat</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.concat(<em>value1</em>,<em>value2</em>,...,<em>valueN</em>)</code>
 * </p>
 * <p>
 * Returns a new array comprised of this array joined with other array(s) and/or value(s).
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>valueN</b></td>
 * <td>Arrays and/or values to concatenate to the resulting array.</td>
 * </tr>
 * </table>
 * @type Array
 */
concat: function() {},

/**
 * <b>reduce</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><varstyle="font-style:italic;">array</var>.reduce(<varstyle="font-style:italic;">callback</var><spanstyle="font-style:italic;">[</span>,<varstyle="font-style:italic;">initialValue</var><spanstyle="font-style:italic;">]</span>)</code>
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>callback previousValue currentValue index array initialValue</b></td>
 * <td>Function to execute on each value in the array, taking four arguments: previousValue The value previously returned in the last invocation of the callback, or initialValue, if supplied. (See below.) currentValue The current element being processed in the array. index The index of the current element being processed in the array. array The array reduce was called upon. The value previously returned in the last invocation of the callback, or initialValue, if supplied. (See below.) The current element being processed in the array. The index of the current element being processed in the array. The array reduce was called upon. Object to use as the first argument to the first call of the callback.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>previousValue currentValue index array</b></td>
 * <td>The value previously returned in the last invocation of the callback, or initialValue, if supplied. (See below.) The current element being processed in the array. The index of the current element being processed in the array. The array reduce was called upon.</td>
 * </tr>
 * </table>
 * @type Object
 */
reduce: function() {},

/**
 * <b>slice</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.slice(<em>begin</em>[,<em>end</em>])</code>
 * </p>
 * <p>
 * Returns a one-level deep copy of a portion of an array.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>end</b></td>
 * <td>Zero-based index at which to end extraction. slice extracts up to but not including end. slice(1,4) extracts the second element through the fourth element (elements indexed 1, 2, and 3). As a negative index, end indicates an offset from the end of the sequence. slice(2,-1) extracts the third element through the second-to-last element in the sequence. If end is omitted, slice extracts to the end of the sequence.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Number</i></td>
 * <td valign="top"><b>begin</b></td>
 * <td>Zero-based index at which to begin extraction. As a negative index, start indicates an offset from the end of the sequence. slice(-2) extracts the second-to-last element and the last element in the sequence.</td>
 * </tr>
 * </table>
 * @type Array
 */
slice: function() {},

/**
 * <b>toString</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.toString()</code>
 * </p>
 * <p>
 * Returns a string representing the specified array and its elements.
 * </p>
 * @type String
 */
toString: function() {},

/**
 * <b>isArray</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>Array.isArray(<em>obj</em>)</code>
 * </p>
 * <p>
 * Returns true if an object is an array, false if it is not.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>obj</b></td>
 * <td>The object to be checked</td>
 * </tr>
 * </table>
 * @type Boolean
 * @static
 */
isArray: function() {},

/**
 * <b>some</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.some(<em>callback</em>[,<em>thisObject</em>])</code>
 * </p>
 * <p>
 * Tests whether some element in the array passes the test implemented by the provided function.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>callback thisObject</b></td>
 * <td>Function to test for each element. Object to use as this when executing callback.</td>
 * </tr>
 * </table>
 * @type Boolean
 */
some: function() {},

/**
 * <b>shift</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.shift()</code>
 * </p>
 * <p>
 * Removes the first element from an array and returns that element. This method changes the length of the array.
 * </p>
 * @type Object
 */
shift: function() {},

/**
 * <b>filter</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>array</em>.filter(<em>callback</em>[,<em>thisObject</em>])</code>
 * </p>
 * <p>
 * Creates a new array with all elements that pass the test implemented by the provided function.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>callback thisObject</b></td>
 * <td>Function to test each element of the array. Object to use as this when executing callback.</td>
 * </tr>
 * </table>
 * @type Array
 */
filter: function() {},

}
