/**
 * <b>Function</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>newFunction([<em>arg1</em>[,<em>arg2</em>[,...<em>argN</em>]],]<em>functionBody</em>)</code>
 * </p>
 * <p>
 * Every function in JavaScript is actually a Function object.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>functionBody</b></td>
 * <td>A string containing the JavaScript statements comprising the function definition.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>arg1, arg2, ... argN</b></td>
 * <td>Names to be used by the function as formal argument names. Each must be a string that corresponds to a valid JavaScript identifier or a list of such strings separated with a comma; for example "x", "theValue", or "a,b".</td>
 * </tr>
 * </table>
 * @type Function
 */
var Function = {
/**
 * <b>caller</b>
 * <p>
 * Returns the function that invoked the specified function. This property is not part of ECMA-262 Edition 3 standard. It is implemented at least in SpiderMonkey (the JavaScript engine used in Mozilla) (see bug 65683 ), V8 (the JavaScript engine used in Chrome) and JScript.
 * </p>
 * @type String
 */
caller: undefined,

/**
 * <b>apply</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>fun</em>.apply(<em>thisArg</em>[,<em>argsArray</em>])</code>
 * </p>
 * <p>
 * Calls a function with a given this value and arguments provided as an array.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b></b></td>
 * <td>The value of this provided for the call to fun.  Note that this may not be the actual value seen by the method: if the method is a function in non-strict mode code, null and undefined will be replaced with the global object, and primitive values will be boxed.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>argsArray</b></td>
 * <td>An array like object, specifying the arguments with which fun should be called, or null or undefined if no arguments should be provided to the function.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>thisArg</b></td>
 * <td></td>
 * </tr>
 * </table>
 * @type Array
 */
apply: function() {},

/**
 * <b>call</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>fun</em>.call(<em>thisArg</em>[,<em>arg1</em>[,<em>arg2</em>[,...]]])</code>
 * </p>
 * <p>
 * Calls a function with a given this value and arguments provided individually.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>arg1, arg2, ...</b></td>
 * <td>Arguments for the object.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>thisArg</b></td>
 * <td>The value of this provided for the call to fun.  Note that this may not be the actual value seen by the method: if the method is a function in non-strict mode code, null and undefined will be replaced with the global object, and primitive values will be boxed.</td>
 * </tr>
 * </table>
 * @type String
 */
call: function() {},

/**
 * <b>toSource</b>
 * <p>
 * Returns a string representing the source code for the function.
 * </p>
 * @type String
 */
toSource: function() {},

/**
 * <b>prototype</b>
 * <p>
 * Represents the Function prototype object.
 * </p>
 * @type Object
 * @static
 */
prototype: undefined,

/**
 * <b>arity</b>
 * <p>
 * Specifies the number of arguments expected by the function.
 * </p>
 * @type Number
 */
arity: undefined,

/**
 * <b>arguments</b>
 * <p>
 * An array-like object corresponding to the arguments passed to a function.
 * </p>
 * @type Array
 */
arguments: undefined,

/**
 * <b>isGenerator</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>result</em>=<em>fun</em>.isGenerator()</code>
 * </p>
 * <p>
 * Determines whether or not a function is a generator.
 * </p>
 * @type Boolean
 */
isGenerator: function() {},

/**
 * <b>name</b>
 * <p>
 * The name of the function.
 * </p>
 * @type String
 */
name: undefined,

/**
 * <b>length</b>
 * <p>
 * Specifies the number of arguments expected by the function.
 * </p>
 * @type Number
 */
length: undefined,

/**
 * <b>toString</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><var>function</var>.toString(<var>indentation</var>)</code>
 * </p>
 * <p>
 * Returns a string representing the source code of the function.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>indentation</b></td>
 * <td>Non-standard The amount of spaces to indent the string representation of the source code. If indentation is less than or equal to -1, most unnecessary spaces are removed.</td>
 * </tr>
 * </table>
 * @type String
 */
toString: function() {},

/**
 * <b>bind</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code><em>fun</em>.bind(<em>thisArg</em>[,<em>arg1</em>[,<em>arg2</em>[,...]]])</code>
 * </p>
 * <p>
 * Creates a new function that, when called, itself calls this function in the context of the provided this value, with a given sequence of arguments preceding any provided when the new function was called.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>thisArg arg1, arg2, ...</b></td>
 * <td>The value to be passed as the this parameter to the target function when the bound function is called.  The value is ignored if the bound function is constructed using the new operator. Arguments to prepend to arguments provided to the bound function when invoking the target function.</td>
 * </tr>
 * </table>
 * @type String
 */
bind: function() {},

/**
 * <b>constructor</b>
 * <p>
 * Returns a reference to the Function function that created the instance's prototype. Note that the value of this property is a reference to the function itself, not a string containing the function's name.
 * </p>
 * @type Function
 */
constructor: undefined,

}
