/**
 * <b>JSON</b>
 * <p>
 * The JSON object contains methods for converting values to JavaScript Object Notation (JSON) and for converting JSON to values. JSON is a syntax for serializing objects, arrays, numbers, strings, booleans, and null.  It is based upon JavaScript syntax but is distinct from it: some JavaScript is not JSON, and some JSON is not JavaScript. The main differences between standard object and array literal notation and JSON are that all property names in a JSON object must be double-quoted strings and that trailing commas in objects and arrays are forbidden.  The main differences between standard number notation and number notation in JSON are that in JSON leading zeroes are prohibited and the decimal point in a number must be followed by at least one digit.  The main differences between standard string notation and string notation in JSON are that in JSON only a limited set of characters may be escaped in strings, certain control characters are prohibited in strings, the Unicode line separator (U+2028) and paragraph separator (U+2029) characters are permitted, and that strings must be double-quoted.   The full JSON syntax is as follows: Insignificant whitespace may be present anywhere except within a JSONNumber (numbers must contain no whitespace) or JSONString (where it is interpreted as the corresponding character in the string, or would cause an error). The tab character (U+0009), carriage return (U+000D), line feed (U+000A), and space (U+0020) characters are the only valid whitespace characters.
 * </p>
 * @type JSON
 */
var JSON = {
/**
 * <b>stringify</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>JSON.stringify(<em>value</em>[,<em>replacer</em>[,<em>space</em>]])</code>
 * </p>
 * <p>
 * Convert a value to JSON, optionally replacing values if a replacer function is specified, or optionally including only the specified properties if a replacer array is specified.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>Array</i></td>
 * <td valign="top"><b>value replacer space</b></td>
 * <td>The value to convert to a JSON string. If a function, transforms values and properties encountered while stringifying; if an array, specifies the set of properties included in objects in the final string. A detailed description of the replacer function is provided in Using native JSON#The_replacer_parameter. Causes the resulting string to be pretty-printed.</td>
 * </tr>
 * </table>
 * @type String
 * @static
 */
stringify: function() {},

/**
 * <b>parse</b>
 * <p style="background-color: #E1FEFF; width: 100%; padding: 5px; margin: 5 5 0 5; border: 2px black dashed;">
 * <code>JSON.parse(<em>text</em>[,<em>reviver</em>])</code>
 * </p>
 * <p>
 * Parse a string as JSON, optionally transforming the value produced by parsing.
 * </p>
 * <h3>Parameters:</h3>
 * <table style="margin-left:10px;">
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>reviver </b></td>
 * <td>If a function, prescribes how the value originally produced by parsing is transformed, before being returned.</td>
 * </tr>
 * <tr>
 * <td valign="top"><i>String</i></td>
 * <td valign="top"><b>text </b></td>
 * <td>The string to parse as JSON.  See the JSON object for a description of JSON syntax.</td>
 * </tr>
 * </table>
 * @type Array|Object
 * @static
 */
parse: function() {},

}
